# ciscotmg

![PyPI](https://img.shields.io/pypi/v/ciscotmg)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ciscotmg)
![GitHub last commit](https://img.shields.io/github/last-commit/robertcsapo/ciscotmg)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/robertcsapo/ciscotmg)
![GitHub issues](https://img.shields.io/github/issues/robertcsapo/ciscotmg)
![GitHub closed issues](https://img.shields.io/github/issues-closed-raw/robertcsapo/ciscotmg)
![Libraries.io dependency status for GitHub repo](https://img.shields.io/librariesio/github/robertcsapo/ciscotmg)
![GitHub Repo stars](https://img.shields.io/github/stars/robertcsapo/ciscotmg?style=social)  

Cisco TMG Matrix Python SDK (as a CLI tool)  
_This is a Private API that is converted in to Python objects and printed in to your terminal_

# Usage
![Help](./img/ciscotmgcli.png)

## Search
```ciscotmg search QSFP-100G-ER```
![Search](./img/ciscotmgcli.search.png)

## Lookup
```ciscotmg lookup QDD-400G-ZR-S```
![Lookup Transceiver](./img/ciscotmgcli.lookup.png)

```ciscotmg lookup -n C9500X-28C8D```
![Lookup Network Device](./img/ciscotmgcli.lookup.n.png)

## Authors & Maintainers

Users responsible for the creation and maintenance of this project:

- Robert Csapo <rcsapo@cisco.com>

## License

This project is licensed to you under the terms of the [Cisco Sample
Code License](./LICENSE).